#[non_exhaustive]pub enum VideoColorPrimaries {
Show 13 variants
Unknown,
Bt709,
Bt470m,
Bt470bg,
Smpte170m,
Smpte240m,
Film,
Bt2020,
Adobergb,
Smptest428,
Smpterp431,
Smpteeg432,
Ebu3213,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unknown
Bt709
Bt470m
Bt470bg
Smpte170m
Smpte240m
Film
Bt2020
Adobergb
Smptest428
Available on crate feature
v1_16 only.Smpterp431
Available on crate feature
v1_16 only.Smpteeg432
Available on crate feature
v1_16 only.Ebu3213
Available on crate feature
v1_16 only.Implementations
sourceimpl VideoColorPrimaries
impl VideoColorPrimaries
pub fn from_iso(value: u32) -> VideoColorPrimaries
Available on crate feature
v1_18 only.pub fn is_equivalent(self, other: VideoColorPrimaries) -> bool
Available on crate feature
v1_22 only.pub fn to_iso(self) -> u32
Available on crate feature
v1_18 only.Trait Implementations
sourceimpl Clone for VideoColorPrimaries
impl Clone for VideoColorPrimaries
sourcefn clone(&self) -> VideoColorPrimaries
fn clone(&self) -> VideoColorPrimaries
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for VideoColorPrimaries
impl Debug for VideoColorPrimaries
sourceimpl From<VideoColorPrimaries> for Value
impl From<VideoColorPrimaries> for Value
sourcefn from(v: VideoColorPrimaries) -> Self
fn from(v: VideoColorPrimaries) -> Self
Converts to this type from the input type.
sourceimpl<'a> FromValue<'a> for VideoColorPrimaries
impl<'a> FromValue<'a> for VideoColorPrimaries
type Checker = GenericValueTypeChecker<VideoColorPrimaries>
type Checker = GenericValueTypeChecker<VideoColorPrimaries>
Value type checker.
sourceunsafe fn from_value(value: &'a Value) -> Self
unsafe fn from_value(value: &'a Value) -> Self
Get the contained value from a
Value. Read moresourceimpl HasParamSpec for VideoColorPrimaries
impl HasParamSpec for VideoColorPrimaries
type ParamSpec = ParamSpecEnum
type SetValue = VideoColorPrimaries
type SetValue = VideoColorPrimaries
Preferred value to be used as setter for the associated ParamSpec.
type BuilderFn = fn(_: &str, _: VideoColorPrimaries) -> ParamSpecEnumBuilder<'_, VideoColorPrimaries>
fn param_spec_builder() -> Self::BuilderFn
sourceimpl Hash for VideoColorPrimaries
impl Hash for VideoColorPrimaries
sourceimpl Ord for VideoColorPrimaries
impl Ord for VideoColorPrimaries
sourcefn cmp(&self, other: &VideoColorPrimaries) -> Ordering
fn cmp(&self, other: &VideoColorPrimaries) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for VideoColorPrimaries
impl PartialEq for VideoColorPrimaries
sourcefn eq(&self, other: &VideoColorPrimaries) -> bool
fn eq(&self, other: &VideoColorPrimaries) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for VideoColorPrimaries
impl PartialOrd for VideoColorPrimaries
sourcefn partial_cmp(&self, other: &VideoColorPrimaries) -> Option<Ordering>
fn partial_cmp(&self, other: &VideoColorPrimaries) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl StaticType for VideoColorPrimaries
impl StaticType for VideoColorPrimaries
sourcefn static_type() -> Type
fn static_type() -> Type
Returns the type identifier of
Self.sourceimpl ToValue for VideoColorPrimaries
impl ToValue for VideoColorPrimaries
sourceimpl ValueType for VideoColorPrimaries
impl ValueType for VideoColorPrimaries
type Type = VideoColorPrimaries
type Type = VideoColorPrimaries
Type to get the
Type from. Read moreimpl Copy for VideoColorPrimaries
impl Eq for VideoColorPrimaries
impl StructuralPartialEq for VideoColorPrimaries