#[non_exhaustive]pub enum VideoOrientationMethod {
Identity,
_90r,
_180,
_90l,
Horiz,
Vert,
UlLr,
UrLl,
Auto,
Custom,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
sourceimpl VideoOrientationMethod
impl VideoOrientationMethod
pub fn from_tag(taglist: &TagListRef) -> Option<VideoOrientationMethod>
Available on crate feature
v1_20 only.Trait Implementations
sourceimpl Clone for VideoOrientationMethod
impl Clone for VideoOrientationMethod
sourcefn clone(&self) -> VideoOrientationMethod
fn clone(&self) -> VideoOrientationMethod
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for VideoOrientationMethod
impl Debug for VideoOrientationMethod
sourceimpl From<VideoOrientationMethod> for Value
impl From<VideoOrientationMethod> for Value
sourcefn from(v: VideoOrientationMethod) -> Self
fn from(v: VideoOrientationMethod) -> Self
Converts to this type from the input type.
sourceimpl<'a> FromValue<'a> for VideoOrientationMethod
impl<'a> FromValue<'a> for VideoOrientationMethod
type Checker = GenericValueTypeChecker<VideoOrientationMethod>
type Checker = GenericValueTypeChecker<VideoOrientationMethod>
Value type checker.
sourceunsafe fn from_value(value: &'a Value) -> Self
unsafe fn from_value(value: &'a Value) -> Self
Get the contained value from a
Value. Read moresourceimpl HasParamSpec for VideoOrientationMethod
impl HasParamSpec for VideoOrientationMethod
type ParamSpec = ParamSpecEnum
type SetValue = VideoOrientationMethod
type SetValue = VideoOrientationMethod
Preferred value to be used as setter for the associated ParamSpec.
type BuilderFn = fn(_: &str, _: VideoOrientationMethod) -> ParamSpecEnumBuilder<'_, VideoOrientationMethod>
fn param_spec_builder() -> Self::BuilderFn
sourceimpl Hash for VideoOrientationMethod
impl Hash for VideoOrientationMethod
sourceimpl Ord for VideoOrientationMethod
impl Ord for VideoOrientationMethod
sourcefn cmp(&self, other: &VideoOrientationMethod) -> Ordering
fn cmp(&self, other: &VideoOrientationMethod) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for VideoOrientationMethod
impl PartialEq for VideoOrientationMethod
sourcefn eq(&self, other: &VideoOrientationMethod) -> bool
fn eq(&self, other: &VideoOrientationMethod) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for VideoOrientationMethod
impl PartialOrd for VideoOrientationMethod
sourcefn partial_cmp(&self, other: &VideoOrientationMethod) -> Option<Ordering>
fn partial_cmp(&self, other: &VideoOrientationMethod) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl StaticType for VideoOrientationMethod
impl StaticType for VideoOrientationMethod
sourcefn static_type() -> Type
fn static_type() -> Type
Returns the type identifier of
Self.sourceimpl ToValue for VideoOrientationMethod
impl ToValue for VideoOrientationMethod
sourceimpl ValueType for VideoOrientationMethod
impl ValueType for VideoOrientationMethod
type Type = VideoOrientationMethod
type Type = VideoOrientationMethod
Type to get the
Type from. Read moreimpl Copy for VideoOrientationMethod
impl Eq for VideoOrientationMethod
impl StructuralPartialEq for VideoOrientationMethod