#[non_exhaustive]pub enum VideoTransferFunction {
Show 17 variants
Unknown,
Gamma10,
Gamma18,
Gamma20,
Gamma22,
Bt709,
Smpte240m,
Srgb,
Gamma28,
Log100,
Log316,
Bt202012,
Adobergb,
Bt202010,
Smpte2084,
AribStdB67,
Bt601,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unknown
Gamma10
Gamma18
Gamma20
Gamma22
Bt709
Smpte240m
Srgb
Gamma28
Log100
Log316
Bt202012
Adobergb
Bt202010
Available on crate feature
v1_18 only.Smpte2084
Available on crate feature
v1_18 only.AribStdB67
Available on crate feature
v1_18 only.Bt601
Available on crate feature
v1_18 only.Implementations
sourceimpl VideoTransferFunction
impl VideoTransferFunction
pub fn decode(self, val: f64) -> f64
Available on crate feature
v1_20 only.pub fn encode(self, val: f64) -> f64
Available on crate feature
v1_20 only.pub fn from_iso(value: u32) -> VideoTransferFunction
Available on crate feature
v1_18 only.pub fn is_equivalent( self, from_bpp: u32, to_func: VideoTransferFunction, to_bpp: u32, ) -> bool
Available on crate feature
v1_18 only.pub fn to_iso(self) -> u32
Available on crate feature
v1_18 only.Trait Implementations
sourceimpl Clone for VideoTransferFunction
impl Clone for VideoTransferFunction
sourcefn clone(&self) -> VideoTransferFunction
fn clone(&self) -> VideoTransferFunction
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for VideoTransferFunction
impl Debug for VideoTransferFunction
sourceimpl From<VideoTransferFunction> for Value
impl From<VideoTransferFunction> for Value
sourcefn from(v: VideoTransferFunction) -> Self
fn from(v: VideoTransferFunction) -> Self
Converts to this type from the input type.
sourceimpl<'a> FromValue<'a> for VideoTransferFunction
impl<'a> FromValue<'a> for VideoTransferFunction
type Checker = GenericValueTypeChecker<VideoTransferFunction>
type Checker = GenericValueTypeChecker<VideoTransferFunction>
Value type checker.
sourceunsafe fn from_value(value: &'a Value) -> Self
unsafe fn from_value(value: &'a Value) -> Self
Get the contained value from a
Value. Read moresourceimpl HasParamSpec for VideoTransferFunction
impl HasParamSpec for VideoTransferFunction
type ParamSpec = ParamSpecEnum
type SetValue = VideoTransferFunction
type SetValue = VideoTransferFunction
Preferred value to be used as setter for the associated ParamSpec.
type BuilderFn = fn(_: &str, _: VideoTransferFunction) -> ParamSpecEnumBuilder<'_, VideoTransferFunction>
fn param_spec_builder() -> Self::BuilderFn
sourceimpl Hash for VideoTransferFunction
impl Hash for VideoTransferFunction
sourceimpl Ord for VideoTransferFunction
impl Ord for VideoTransferFunction
sourcefn cmp(&self, other: &VideoTransferFunction) -> Ordering
fn cmp(&self, other: &VideoTransferFunction) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for VideoTransferFunction
impl PartialEq for VideoTransferFunction
sourcefn eq(&self, other: &VideoTransferFunction) -> bool
fn eq(&self, other: &VideoTransferFunction) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for VideoTransferFunction
impl PartialOrd for VideoTransferFunction
sourcefn partial_cmp(&self, other: &VideoTransferFunction) -> Option<Ordering>
fn partial_cmp(&self, other: &VideoTransferFunction) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl StaticType for VideoTransferFunction
impl StaticType for VideoTransferFunction
sourcefn static_type() -> Type
fn static_type() -> Type
Returns the type identifier of
Self.sourceimpl ToValue for VideoTransferFunction
impl ToValue for VideoTransferFunction
sourceimpl ValueType for VideoTransferFunction
impl ValueType for VideoTransferFunction
type Type = VideoTransferFunction
type Type = VideoTransferFunction
Type to get the
Type from. Read moreimpl Copy for VideoTransferFunction
impl Eq for VideoTransferFunction
impl StructuralPartialEq for VideoTransferFunction